PCB Environment: Globals

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all macros with links to the files they belong to:

### - _ -

- _PCB_GYM_LOG_IF : Log.hpp

### - a -

- ASTAR_ALLOW_XOVER : AStar.hpp

### - c -

- CGAL_DISABLE_ROUNDING_MATH_CHECK : Geometry.hpp

### - d -

- DEBUG : Log.hpp

### - e -

- ERROR : Log.hpp

### - g -

- GYM_PCB_LOG_FORMAT_TIME : Log.hpp
- GYM_PCB_LOG_SHOW_THREAD : Log.hpp
- GYM_PCB_MAX_LOG_LEVEL : Log.hpp
- GYM_PCB_NAVPOINT_NUM_COST_TERMS : NavPoint.hpp

### - i -

- INFO : Log.hpp

### - n -

- NAV_IMAGE_CHAN_PIN_B : NavImage.hpp
- NAV_IMAGE_CHAN_PIN_T : NavImage.hpp
- NAV_IMAGE_CHAN_RATSNEST_B : NavImage.hpp
- NAV_IMAGE_CHAN_RATSNEST_T : NavImage.hpp
- NAV_IMAGE_CHAN_TRACK_B : NavImage.hpp
- NAV_IMAGE_CHAN_TRACK_M : NavImage.hpp
- NAV_IMAGE_CHAN_TRACK_T : NavImage.hpp
- NAV_IMAGE_CHAN_VIA : NavImage.hpp
- NAV_IMAGE_NUM_CHANS : NavImage.hpp
- NAV_POINT_FLAG_BLOCKED_PERMANENT : NavPoint.hpp
- NAV_POINT_FLAG_BLOCKED_TEMPORARY : NavPoint.hpp
- NAV_POINT_FLAG_INSIDE_COMPONENT : NavPoint.hpp
- NAV_POINT_FLAG_INSIDE_PIN : NavPoint.hpp
- NAV_POINT_FLAG_NO_VIAS : NavPoint.hpp
- NAV_POINT_FLAG_PIN_TRACK_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAG_PIN_VIA_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAG_ROUTE_GUARD : NavPoint.hpp
- NAV_POINT_FLAG_ROUTE_TRACK_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAG_ROUTE_VIA_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAG_SOURCE : NavPoint.hpp
- NAV_POINT_FLAG_TARGET : NavPoint.hpp
- NAV_POINT_FLAGS_ALL : NavPoint.hpp
- NAV_POINT_FLAGS_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAGS_ENDPOINT : NavPoint.hpp
- NAV_POINT_FLAGS_PIN_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAGS_ROUTE_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAGS_TRACK_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAGS_TRACKS_BLOCKED : NavPoint.hpp
- NAV_POINT_FLAGS_VIA_CLEARANCE : NavPoint.hpp
- NAV_POINT_FLAGS_VIAS_BLOCKED : NavPoint.hpp
- NAV_POINT_FLAGS_VIAS_BLOCKED_P : NavPoint.hpp
- NO_IMPORT_ARRAY : Py.hpp
- NOTICE : Log.hpp
- NPY_NO_DEPRECATED_API : Py.hpp

### - p -

- PCB_CHANGED_COMPONENTS : PCBoard.hpp
- PCB_CHANGED_NAV_GRID : PCBoard.hpp
- PCB_CHANGED_NAV_TRIS : PCBoard.hpp
- PCB_CHANGED_NET_COLORS : PCBoard.hpp
- PCB_CHANGED_NEW_BOARD : PCBoard.hpp
- PCB_CHANGED_OBJECTS : PCBoard.hpp
- PCB_CHANGED_OBJECTS_SET : PCBoard.hpp
- PCB_CHANGED_PINS : PCBoard.hpp
- PCB_CHANGED_ROUTES : PCBoard.hpp
- PEDANTIC : Defs.hpp
- PERF_COUNTER_D : AStar.hpp
- PERF_COUNTER_T : AStar.hpp
- PY_ARRAY_UNIQUE_SYMBOL : Py.hpp
- PY_ONLY : Py.hpp

### - r -

- RASTERIZE_CAPS_MASK_BOTH : Rasterizer.hpp
- RASTERIZE_CAPS_MASK_SOURCE : Rasterizer.hpp
- RASTERIZE_CAPS_MASK_TARGET : Rasterizer.hpp
- RASTERIZE_MASK_ALL : Rasterizer.hpp
- RASTERIZE_MASK_CAPS : Rasterizer.hpp
- RASTERIZE_MASK_CAPS_AND_JUNCTIONS : Rasterizer.hpp
- RASTERIZE_MASK_JUNCTIONS : Rasterizer.hpp
- RASTERIZE_MASK_SEGMENTS : Rasterizer.hpp
- RASTERIZE_MASK_VIAS : Rasterizer.hpp
- RETURN_ERROR : Log.hpp

### - s -

- std_08x : Defs.hpp
- std_get_for_cgal : Geometry.hpp

### - t -

- TRACE : Log.hpp

### - w -

- WARN : Log.hpp
- WITH_LOCK : Defs.hpp
- WITH_LOCKGUARD : FancyLock.hpp
- WITH_RLOCK : Defs.hpp
- WITH_WLOCK : Defs.hpp